# MultiRepast4py
MultiRepast4py is a python package that enable Multilayer Simulation on Repast4py. Follow the tutorial to setup the environment and run your own multilayer simulations!

Follow the guide to install Repast4py: https://repast.github.io/repast4py.site/index.html

pip install git+https://github.com/KengLL/MultiRepast4py.git
